@@ -7,6 +7,9 @@ from .ansitowin32 import AnsiToWin32
 orig_stdout = sys.stdout
 orig_stderr = sys.stderr
 
+wrapped_stdout = sys.stdout
+wrapped_stderr = sys.stderr
+
 atexit_done = False
 
 
@@ -16,11 +19,13 @@ def reset_all():
 
 def init(autoreset=False, convert=None, strip=None, wrap=True):
 
-    if wrap==False and (autoreset==True or convert==True or strip==True):
+    if wrap and any(autoreset, convert, strip):
         raise ValueError('wrap=False conflicts with any other arg=True')
 
-    sys.stdout = wrap_stream(orig_stdout, convert, strip, autoreset, wrap)
-    sys.stderr = wrap_stream(orig_stderr, convert, strip, autoreset, wrap)
+    sys.stdout = wrapped_stdout = \
+        wrap_stream(orig_stdout, convert, strip, autoreset, wrap)
+    sys.stderr = wrapped_stderr = \
+        wrap_stream(orig_stderr, convert, strip, autoreset, wrap)
 
     global atexit_done
     if not atexit_done:
@@ -28,10 +33,22 @@ def init(autoreset=False, convert=None, strip=None, wrap=True):
         atexit_done = True
 
 
+def deinit():
+    sys.stdout = orig_stdout
+    sys.stderr = orig_stderr
+
+
+def reinit():
+    sys.stdout = wrapped_stdout
+    sys.stderr = wrapped_stdout
+
+
 def wrap_stream(stream, convert, strip, autoreset, wrap):
     if wrap:
         wrapper = AnsiToWin32(stream,
             convert=convert, strip=strip, autoreset=autoreset)
         if wrapper.should_wrap():
             stream = wrapper.stream
-    return stream
\ No newline at end of file
+    return stream
+
+
